@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-itip-control.c
- *
- * Copyright (C) 2001  Ximian, Inc.
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		JP Rosevear <jpr@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: JP Rosevear
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,15 +29,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-#include <gtk/gtkmisc.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-uidefs.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
+#include <glib/gstdio.h>
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-exception.h>
 #include <gtkhtml/gtkhtml.h>
@@ -668,7 +661,7 @@ write_label_piece (EItipControl *itip, ECalComponentDateTime *dt,
 	struct tm tmp_tm;
 	char time_buf[64];
 	icaltimezone *zone = NULL;
-	char *display_name;
+	const char *display_name;
 
 	priv = itip->priv;
 
@@ -874,7 +867,7 @@ write_recurrence_piece (EItipControl *itip, ECalComponent *comp,
 	      /* For Translators:'a total of %d times' is part of the sentence of the form 'event recurring every day,a total of % times.' %d is a digit*/
 		g_string_append_printf (
 			buffer, ngettext ("a total of %d time",
-			" a total of %d times", r->count), r->count);
+			"a total of %d times", r->count), r->count);
 	} else if (!icaltime_is_null_time (r->until)) {
 		ECalComponentDateTime dt;
 
@@ -1957,7 +1950,7 @@ update_item (EItipControl *itip)
 	 * and you then look at it in Outlook).
 	 */
 	stamp = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
-	str = icaltime_as_ical_string (stamp);
+	str = icaltime_as_ical_string_r (stamp);
 	prop = icalproperty_new_x (str);
 	g_free (str);
 	icalproperty_set_x_name (prop, "X-MICROSOFT-CDO-REPLYTIME");
@@ -2104,7 +2097,7 @@ send_item (EItipControl *itip)
 	comp = get_real_item (itip);
 
 	if (comp != NULL) {
-		itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, priv->current_ecal, NULL, NULL, NULL);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_REQUEST, comp, priv->current_ecal, NULL, NULL, NULL, TRUE);
 		g_object_unref (comp);
 		dialog = gtk_message_dialog_new (
 			NULL, 0,
@@ -2159,7 +2152,7 @@ send_freebusy (EItipControl *itip)
 
 		for (l = comp_list; l; l = l->next) {
 			ECalComponent *comp = E_CAL_COMPONENT (l->data);
-			itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, NULL, NULL, NULL);
+			itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, NULL, NULL, NULL, TRUE);
 
 			g_object_unref (comp);
 		}
@@ -2284,7 +2277,7 @@ insert_rsvp (GtkWidget *hbox, EItipControl *itip)
 	priv = itip->priv;
 
 	/* To translators: RSVP means "please reply" */
-	btn = gtk_check_button_new_with_label ("RSVP");
+	btn = gtk_check_button_new_with_label (_("RSVP"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (btn), TRUE);
 	priv->rsvp = TRUE;
 
@@ -2605,7 +2598,7 @@ ok_clicked_cb (GtkWidget *widget, gpointer data)
 		g_slist_free (list);
 
 		e_cal_component_rescan (comp);
-		itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, priv->top_level, NULL, NULL);
+		itip_send_comp (E_CAL_COMPONENT_METHOD_REPLY, comp, priv->current_ecal, priv->top_level, NULL, NULL, TRUE);
 
 		g_object_unref (comp);
 	}
