@@ -73,7 +73,7 @@
 #include "em-utils.h"
 #include "em-migrate.h"
 
-#define d(x) x
+#define d(x)
 
 #ifndef G_OS_WIN32
 /* No versions previous to 2.8 or thereabouts have been available on
@@ -2848,7 +2848,7 @@ update_progress_in_main_thread (double *progress)
 		em_migrate_set_progress (*progress);
 		return FALSE;
 }
- 
+
 static void
 migrate_folders(CamelStore *store, gboolean is_local, CamelFolderInfo *fi, const char *acc, CamelException *ex, gboolean *done, int *nth_folder, int total_folders)
 {
@@ -2856,10 +2856,11 @@ migrate_folders(CamelStore *store, gboolean is_local, CamelFolderInfo *fi, const
 
 	while (fi) {
 		double progress;
+		char *tmp;
 
 		*nth_folder = *nth_folder + 1;
 
-		char *tmp = g_strdup_printf ("%s/%s", acc, fi->full_name);
+		tmp = g_strdup_printf ("%s/%s", acc, fi->full_name);
 		em_migrate_set_folder_name (tmp);
 		g_free (tmp);
 		
@@ -2950,13 +2951,14 @@ migrate_to_db()
 		camel_session_set_online ((CamelSession *) session, FALSE);
 
 		em_migrate_setup_progress_dialog (_("The summary format of the Evolution mailbox "
-								"folders has been moved to sqlite since Evolution 2.24.\n\nPlease be "
+								"folders has been moved to SQLite since Evolution 2.24.\n\nPlease be "
 								"patient while Evolution migrates your folders..."));
 
 		store = setup_local_store (component);
 		info = camel_store_get_folder_info (store, NULL, CAMEL_STORE_FOLDER_INFO_RECURSIVE|CAMEL_STORE_FOLDER_INFO_FAST|CAMEL_STORE_FOLDER_INFO_SUBSCRIBED, NULL);	
 
 		if (info) {
+				GThread *thread;
 				struct migrate_folders_to_db_structure migrate_dbs;
 
 				if (g_str_has_suffix (((CamelService *)store)->url->path, ".evolution/mail/local"))
@@ -2969,7 +2971,6 @@ migrate_to_db()
 				migrate_dbs.store = store;
 				migrate_dbs.done = FALSE;
 
-				GThread *thread;
 				thread = g_thread_create ((GThreadFunc) migrate_folders_to_db_thread, &migrate_dbs, TRUE, NULL);
 				while (!migrate_dbs.done)
 						g_main_context_iteration (NULL, TRUE);
@@ -2995,6 +2996,7 @@ migrate_to_db()
 						store = (CamelStore *) camel_session_get_service (session, service->url, CAMEL_PROVIDER_STORE, &ex);
 						info = camel_store_get_folder_info (store, NULL, CAMEL_STORE_FOLDER_INFO_RECURSIVE|CAMEL_STORE_FOLDER_INFO_FAST|CAMEL_STORE_FOLDER_INFO_SUBSCRIBED, &ex);
 						if (info) {
+								GThread *thread;
 								struct migrate_folders_to_db_structure migrate_dbs;
 
 								migrate_dbs.ex = ex;
@@ -3003,7 +3005,6 @@ migrate_to_db()
 								migrate_dbs.store = store;
 								migrate_dbs.done = FALSE;
 
-								GThread *thread;
 								thread = g_thread_create ((GThreadFunc) migrate_folders_to_db_thread, &migrate_dbs, TRUE, NULL);
 								while (!migrate_dbs.done)
 										g_main_context_iteration (NULL, TRUE);
@@ -3018,6 +3019,7 @@ migrate_to_db()
 		g_object_unref (iter);
 		em_migrate_close_progress_dialog ();
 }
+  
 
 int
 em_migrate (const char *evolution_dir, int major, int minor, int revision, CamelException *ex)
@@ -3118,7 +3120,7 @@ em_migrate (const char *evolution_dir, int major, int minor, int revision, Camel
 
 	if (major < 2 || (major == 2 && minor < 24)) {
 		em_update_sa_junk_setting_2_23 ();
-		migrate_to_db();
+		migrate_to_db ();
 	}
 
 	return 0;
