@@ -121,6 +121,8 @@ struct _ItipViewPrivate {
 
 	GtkWidget *options_box;
 	GtkWidget *free_time_check;
+	GtkWidget *keep_alarm_check;
+	GtkWidget *inherit_alarm_check;
 
 	GtkWidget *button_box;
 	gboolean buttons_sensitive;
@@ -735,7 +737,6 @@ set_info_items (GtkWidget *info_box, GSList *info_items)
 		}
 
 		label = gtk_label_new (item->message);
-		gtk_label_set_selectable (GTK_LABEL (label), TRUE);		
 		gtk_widget_show (label);
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 6);
 
@@ -948,6 +949,18 @@ recur_toggled_cb (GtkWidget *widget, gpointer data)
 	itip_view_set_mode (view, priv->mode);
 }
 
+/*
+  alarm_check_toggled_cb
+  check1 was changed, so make the second available based on state of the first check.
+*/
+static void
+alarm_check_toggled_cb (GtkWidget *check1, GtkWidget *check2)
+{
+	g_return_if_fail (check1 != NULL);
+	g_return_if_fail (check2 != NULL);
+
+	gtk_widget_set_sensitive (check2, !(GTK_WIDGET_VISIBLE (check1) && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check1))));
+}
 
 static void
 itip_view_init (ItipView *view)
@@ -978,7 +991,6 @@ itip_view_init (ItipView *view)
 	/* The first section listing the sender */
 	/* FIXME What to do if the send and organizer do not match */
 	priv->sender_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->sender_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->sender_label), 0, 0.5);
 	gtk_widget_show (priv->sender_label);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->sender_label, FALSE, FALSE, 0);
@@ -996,7 +1008,6 @@ itip_view_init (ItipView *view)
 
 	/* Summary */
 	priv->summary_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->summary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->summary_label), 0, 0.5);
 	gtk_label_set_line_wrap_mode (GTK_LABEL (priv->summary_label), PANGO_WRAP_WORD);
 	gtk_label_set_line_wrap (GTK_LABEL (priv->summary_label), TRUE);
@@ -1006,8 +1017,6 @@ itip_view_init (ItipView *view)
 	/* Location */
 	priv->location_header = gtk_label_new (_("Location:"));
 	priv->location_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->location_header), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->location_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->location_header), 0, 0.5);
 	gtk_misc_set_alignment (GTK_MISC (priv->location_label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), priv->location_header, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
@@ -1016,8 +1025,6 @@ itip_view_init (ItipView *view)
 	/* Start time */
 	priv->start_header = gtk_label_new (_("Start time:"));
 	priv->start_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->start_header), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->start_label), TRUE);	
 	gtk_misc_set_alignment (GTK_MISC (priv->start_header), 0, 0.5);
 	gtk_misc_set_alignment (GTK_MISC (priv->start_label), 0, 0.5);
 	gtk_widget_show (priv->start_header);
@@ -1027,8 +1034,6 @@ itip_view_init (ItipView *view)
 	/* End time */
 	priv->end_header = gtk_label_new (_("End time:"));
 	priv->end_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->end_header), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->end_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->end_header), 0, 0.5);
 	gtk_misc_set_alignment (GTK_MISC (priv->end_label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), priv->end_header, 0, 1, 3, 4, GTK_FILL, 0, 0, 0);
@@ -1037,8 +1042,6 @@ itip_view_init (ItipView *view)
 	/* Status */
 	priv->status_header = gtk_label_new (_("Status:"));
 	priv->status_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->status_header), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->status_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->status_header), 0, 0.5);
 	gtk_misc_set_alignment (GTK_MISC (priv->status_label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), priv->status_header, 0, 1, 4, 5, GTK_FILL, 0, 0, 0);
@@ -1047,8 +1050,6 @@ itip_view_init (ItipView *view)
 	/* Comment */
 	priv->comment_header = gtk_label_new (_("Comment:"));
 	priv->comment_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->comment_header), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (priv->comment_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->comment_header), 0, 0.5);
 	gtk_misc_set_alignment (GTK_MISC (priv->comment_label), 0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), priv->comment_header, 0, 1, 5, 6, GTK_FILL, 0, 0, 0);
@@ -1061,7 +1062,6 @@ itip_view_init (ItipView *view)
 
 	/* Description */
 	priv->description_label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (priv->description_label), TRUE);	
 	gtk_label_set_line_wrap (GTK_LABEL (priv->description_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (priv->description_label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (vbox), priv->description_label, FALSE, FALSE, 0);
@@ -1095,12 +1095,10 @@ itip_view_init (ItipView *view)
 	gtk_box_pack_start (GTK_BOX (priv->rsvp_box), hbox, FALSE, FALSE, 0);
 
 	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);	
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
 	priv->rsvp_comment_header = gtk_label_new (_("Comment:"));
-	gtk_label_set_selectable (GTK_LABEL (priv->rsvp_comment_header), TRUE);	
 	gtk_widget_set_sensitive (priv->rsvp_comment_header, FALSE);
 	gtk_widget_show (priv->rsvp_comment_header);
 	gtk_box_pack_start (GTK_BOX (hbox), priv->rsvp_comment_header, FALSE, FALSE, 0);
@@ -1135,6 +1133,17 @@ itip_view_init (ItipView *view)
 	priv->free_time_check = gtk_check_button_new_with_mnemonic (_("Show time as _free"));
 	gtk_box_pack_start (GTK_BOX (priv->options_box), priv->free_time_check, FALSE, FALSE, 0);
 
+	priv->keep_alarm_check = gtk_check_button_new_with_mnemonic (_("_Preserve my reminder"));
+	/* default value is to keep user's alarms */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->priv->keep_alarm_check), TRUE);
+	gtk_box_pack_start (GTK_BOX (priv->options_box), priv->keep_alarm_check, FALSE, FALSE, 0);
+
+	priv->inherit_alarm_check = gtk_check_button_new_with_mnemonic (_("_Inherit reminder"));
+	gtk_box_pack_start (GTK_BOX (priv->options_box), priv->inherit_alarm_check, FALSE, FALSE, 0);
+
+	g_signal_connect (priv->keep_alarm_check, "toggled", G_CALLBACK (alarm_check_toggled_cb), priv->inherit_alarm_check);
+	g_signal_connect (priv->inherit_alarm_check, "toggled", G_CALLBACK (alarm_check_toggled_cb), priv->keep_alarm_check);
+
 	/* The buttons for actions */
 	priv->button_box = gtk_hbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (priv->button_box), GTK_BUTTONBOX_START);
@@ -1887,7 +1896,6 @@ itip_view_set_source_list (ItipView *view, ESourceList *source_list)
 		else if (priv->type == E_CAL_SOURCE_TYPE_JOURNAL)
 			priv->escb_header = gtk_label_new_with_mnemonic (_("Memos :"));
 
-		gtk_label_set_selectable (GTK_LABEL (priv->escb_header), TRUE);
 		gtk_label_set_mnemonic_widget (GTK_LABEL (priv->escb_header), priv->escb);
 		gtk_widget_show (priv->escb_header);
 	}
@@ -2135,7 +2143,7 @@ itip_view_set_show_recur_check (ItipView *view, gboolean show)
 
 	if (show)
 		gtk_widget_show (view->priv->recur_check);
-	else  {
+	else {
 		gtk_widget_hide (view->priv->recur_check);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->priv->recur_check), FALSE);
 	}
@@ -2149,7 +2157,7 @@ itip_view_set_show_free_time_check (ItipView *view, gboolean show)
 	
 	if (show)
 		gtk_widget_show (view->priv->free_time_check);
-	else  {
+	else {
 		gtk_widget_hide (view->priv->free_time_check);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->priv->free_time_check), FALSE);
 	}
@@ -2162,3 +2170,51 @@ itip_view_get_free_time_check_state (ItipView *view)
 
 	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (view->priv->free_time_check));
 }
+
+void
+itip_view_set_show_keep_alarm_check (ItipView *view, gboolean show)
+{
+	g_return_if_fail (view != NULL);
+	g_return_if_fail (ITIP_IS_VIEW (view));	
+	
+	if (show)
+		gtk_widget_show (view->priv->keep_alarm_check);
+	else
+		gtk_widget_hide (view->priv->keep_alarm_check);
+
+	/* and update state of the second check */
+	alarm_check_toggled_cb (view->priv->keep_alarm_check, view->priv->inherit_alarm_check);
+}
+
+gboolean
+itip_view_get_keep_alarm_check_state (ItipView *view)
+{
+	g_return_val_if_fail (view != NULL, FALSE);
+
+	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (view->priv->keep_alarm_check));
+}
+
+void
+itip_view_set_show_inherit_alarm_check (ItipView *view, gboolean show)
+{
+	g_return_if_fail (view != NULL);
+	g_return_if_fail (ITIP_IS_VIEW (view));	
+	
+	if (show)
+		gtk_widget_show (view->priv->inherit_alarm_check);
+	else {
+		gtk_widget_hide (view->priv->inherit_alarm_check);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (view->priv->inherit_alarm_check), FALSE);
+	}
+
+	/* and update state of the second check */
+	alarm_check_toggled_cb (view->priv->inherit_alarm_check, view->priv->keep_alarm_check);
+}
+
+gboolean
+itip_view_get_inherit_alarm_check_state (ItipView *view)
+{
+	g_return_val_if_fail (view != NULL, FALSE);
+
+	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (view->priv->inherit_alarm_check));
+}
