@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-sidebar.c
- *
- * Copyright (C) 2003  Ettore Perazzoli
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,12 +28,6 @@
 
 #include "e-shell-marshal.h"
 
-#include <gtk/gtk.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktogglebutton.h>
-
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-gconf.h>
 
@@ -42,16 +36,16 @@ typedef struct {
 	GtkWidget *label;
 	GtkWidget *icon;
 	GtkWidget *hbox;
-	GtkTooltips *tooltips;
+	gchar *default_icon_name;
 	int id;
 } Button;
 
 struct _ESidebarPrivate {
 	ESidebarMode mode;
 	ESidebarMode toolbar_mode;
-	
+
 	gboolean show;
-	
+
 	GtkWidget *selection_widget;
 	GSList *buttons;
 
@@ -78,23 +72,28 @@ G_DEFINE_TYPE (ESidebar, e_sidebar, GTK_TYPE_CONTAINER)
 /* Utility functions.  */
 
 static Button *
-button_new (GtkWidget *button_widget, GtkWidget *label, GtkWidget *icon, GtkTooltips *tooltips,
-	    GtkWidget *hbox, int id)
+button_new (GtkWidget *button_widget,
+	    GtkWidget *label,
+	    GtkWidget *icon,
+	    GtkWidget *hbox,
+	    int        id)
 {
 	Button *button = g_new (Button, 1);
+	const gchar *icon_name;
 
 	button->button_widget = button_widget;
 	button->label = label;
-	button->icon = icon;
+        button->icon = icon;
 	button->hbox = hbox;
-	button->tooltips = tooltips;
 	button->id = id;
 
+	gtk_image_get_icon_name (GTK_IMAGE (icon), &icon_name, NULL);
+	button->default_icon_name = g_strdup (icon_name);
+
 	g_object_ref (button_widget);
 	g_object_ref (label);
-	g_object_ref (icon);
+        g_object_ref (icon);
 	g_object_ref (hbox);
-	g_object_ref (tooltips);
 
 	return button;
 }
@@ -106,7 +105,7 @@ button_free (Button *button)
 	g_object_unref (button->label);
 	g_object_unref (button->icon);
 	g_object_unref (button->hbox);
-	g_object_unref (button->tooltips);
+	g_free (button->default_icon_name);
 	g_free (button);
 }
 
@@ -184,6 +183,30 @@ button_pressed_callback (GtkToggleButton *toggle_button,
 	return return_val;
 }
 
+static gboolean
+button_query_tooltip (GtkWidget  *widget,
+		      gint        x,
+		      gint        y,
+		      gboolean    keyboard_mode,
+		      GtkTooltip *tooltip,
+		      ESidebar   *sidebar)
+{
+	/* Show the tooltip only if the label is hidden */
+	if (INTERNAL_MODE (sidebar) == E_SIDEBAR_MODE_ICON) {
+		char *tip;
+
+		tip = g_object_get_data (G_OBJECT (widget),
+					 "ESidebar:button-tooltip");
+		if (tip) {
+			gtk_tooltip_set_text (tooltip, tip);
+
+			return TRUE;
+		}
+	}
+
+	return FALSE;
+}
+
 
 /* Layout. */
 
@@ -218,7 +241,7 @@ layout_buttons (ESidebar *sidebar)
 		gtk_widget_size_request (GTK_WIDGET (button->button_widget), &requisition);
 
 		max_btn_height = MAX (max_btn_height, requisition.height);
-		max_btn_width = MAX (max_btn_width, requisition.width);	
+		max_btn_width = MAX (max_btn_width, requisition.width);
 	}
 
 	/* Figure out how many rows and columns we'll use. */
@@ -260,7 +283,7 @@ layout_buttons (ESidebar *sidebar)
 	/* Layout the buttons. */
 	for (i = row_last; i >= 0; i --) {
 		int len, extra_width;
-		
+
 		y -= max_btn_height;
 		x = H_PADDING + allocation->x;
 		len = g_slist_length (rows[i]);
@@ -302,13 +325,13 @@ do_layout (ESidebar *sidebar)
 		y = layout_buttons (sidebar);
 	else
 		y = allocation->y + allocation->height;
-	
+
 	/* Place the selection widget.  */
 	child_allocation.x = allocation->x;
 	child_allocation.y = allocation->y;
 	child_allocation.width = allocation->width;
 	child_allocation.height = y - allocation->y;
-	
+
 	gtk_widget_size_allocate (sidebar->priv->selection_widget, & child_allocation);
 }
 
@@ -376,7 +399,7 @@ impl_size_request (GtkWidget *widget,
 
 	if (!sidebar->priv->show)
 		return;
-	
+
 	for (p = sidebar->priv->buttons; p != NULL; p = p->next) {
 		Button *button = p->data;
 		GtkRequisition button_requisition;
@@ -414,7 +437,7 @@ impl_dispose (GObject *object)
 		gconf_client_notify_remove (gconf_client, priv->style_changed_id);
 		priv->style_changed_id = 0;
 	}
-	
+
  	g_object_unref (gconf_client);
 
 	(* G_OBJECT_CLASS (e_sidebar_parent_class)->dispose) (object);
@@ -427,7 +450,7 @@ boolean_handled_accumulator (GSignalInvocationHint *ihint,
 			     gpointer               dummy)
 {
 	gboolean handled;
-	
+
 	handled = g_value_get_boolean (handler_return);
 	g_value_set_boolean (return_accu, handled);
 
@@ -469,7 +492,7 @@ e_sidebar_class_init (ESidebarClass *klass)
 				G_SIGNAL_RUN_FIRST,
 				G_STRUCT_OFFSET (ESidebarClass, button_selected),
 				NULL, NULL,
-				e_shell_marshal_NONE__INT,
+				g_cclosure_marshal_VOID__INT,
 				G_TYPE_NONE, 1,
 				G_TYPE_INT);
 	signals[BUTTON_PRESSED]
@@ -489,7 +512,7 @@ e_sidebar_init (ESidebar *sidebar)
 	ESidebarPrivate *priv;
 
 	GTK_WIDGET_SET_FLAGS (sidebar, GTK_NO_WINDOW);
-  
+
 	priv = g_new0 (ESidebarPrivate, 1);
 	sidebar->priv = priv;
 
@@ -524,14 +547,13 @@ void
 e_sidebar_add_button (ESidebar *sidebar,
 		      const char *label,
 		      const char *tooltips,
-		      GdkPixbuf *icon,
+		      const char *icon_name,
 		      int id)
 {
 	GtkWidget *button_widget;
 	GtkWidget *hbox;
 	GtkWidget *icon_widget;
 	GtkWidget *label_widget;
-	GtkTooltips *button_tooltips;
 
 	button_widget = gtk_toggle_button_new ();
 	if (sidebar->priv->show)
@@ -544,40 +566,78 @@ e_sidebar_add_button (ESidebar *sidebar,
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
 	gtk_widget_show (hbox);
 
-	icon_widget = gtk_image_new_from_pixbuf (icon);
+	icon_widget = gtk_image_new_from_icon_name (
+		icon_name, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (icon_widget);
-	
+
 	label_widget = gtk_label_new (label);
 	gtk_misc_set_alignment (GTK_MISC (label_widget), 0.0, 0.5);
 	gtk_widget_show (label_widget);
-	button_tooltips = gtk_tooltips_new();
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (button_tooltips), button_widget, tooltips, NULL);		
+
+	g_object_set_data_full (G_OBJECT (button_widget),
+				"ESidebar:button-tooltip",
+				g_strdup (tooltips),
+				g_free);
+	gtk_widget_set_has_tooltip (button_widget, TRUE);
+	g_signal_connect (button_widget, "query-tooltip",
+			  G_CALLBACK (button_query_tooltip), sidebar);
 
 	switch (INTERNAL_MODE (sidebar)) {
 	case E_SIDEBAR_MODE_TEXT:
 		gtk_box_pack_start (GTK_BOX (hbox), label_widget, TRUE, TRUE, 0);
-		gtk_tooltips_disable (button_tooltips);
 		break;
 	case E_SIDEBAR_MODE_ICON:
 		gtk_box_pack_start (GTK_BOX (hbox), icon_widget, TRUE, TRUE, 0);
-		gtk_tooltips_enable (button_tooltips);
 		break;
 	case E_SIDEBAR_MODE_BOTH:
 	default:
 		gtk_box_pack_start (GTK_BOX (hbox), icon_widget, FALSE, TRUE, 0);
 		gtk_box_pack_start (GTK_BOX (hbox), label_widget, TRUE, TRUE, 0);
-		gtk_tooltips_disable (button_tooltips);
 		break;
 	}
 
 	gtk_container_add (GTK_CONTAINER (button_widget), hbox);
 
-	sidebar->priv->buttons = g_slist_append (sidebar->priv->buttons, button_new (button_widget, label_widget, icon_widget, button_tooltips, hbox, id));
+	sidebar->priv->buttons = g_slist_append (sidebar->priv->buttons, button_new (button_widget, label_widget, icon_widget, hbox, id));
 	gtk_widget_set_parent (button_widget, GTK_WIDGET (sidebar));
 
 	gtk_widget_queue_resize (GTK_WIDGET (sidebar));
 }
 
+/**
+ * e_sidebar_change_button_icon
+ * @sidebar: an #ESidebar
+ * @icon_name: button icon name, or %NULL
+ * @button_id: component's button ID, for which change the icon.
+ *
+ * This will change icon in icon_widget of the button of known component.
+ * You cannot change icon as in a stack, only one default icon will be stored.
+ **/
+void
+e_sidebar_change_button_icon (ESidebar *sidebar, const gchar *icon_name, int button_id)
+{
+	GSList *p;
+
+	g_return_if_fail (sidebar != NULL);
+
+	for (p = sidebar->priv->buttons; p != NULL; p = p->next) {
+		Button *button = p->data;
+
+		if (button->id == button_id) {
+			if (!button->icon)
+				break;
+
+			if (icon_name == NULL)
+				icon_name = button->default_icon_name;
+
+			gtk_image_set_from_icon_name (
+				GTK_IMAGE (button->icon),
+				icon_name, GTK_ICON_SIZE_BUTTON);
+
+			break;
+		}
+	}
+}
 
 void
 e_sidebar_select_button (ESidebar *sidebar, int id)
@@ -610,7 +670,7 @@ set_mode_internal (ESidebar *sidebar, ESidebarMode mode )
 
 	if (mode == INTERNAL_MODE (sidebar))
 		return;
-	
+
 	for (p = sidebar->priv->buttons; p != NULL; p = p->next) {
 		Button *button = p->data;
 
@@ -620,7 +680,6 @@ set_mode_internal (ESidebar *sidebar, ESidebarMode mode )
 			if (INTERNAL_MODE (sidebar) == E_SIDEBAR_MODE_ICON) {
 				gtk_box_pack_start (GTK_BOX (button->hbox), button->label, TRUE, TRUE, 0);
 				gtk_widget_show (button->label);
-				gtk_tooltips_disable (button->tooltips);
 			}
 			break;
 		case E_SIDEBAR_MODE_ICON:
@@ -632,7 +691,6 @@ set_mode_internal (ESidebar *sidebar, ESidebarMode mode )
 				gtk_container_child_set (GTK_CONTAINER (button->hbox), button->icon,
 							 "expand", TRUE,
 							 NULL);
-			gtk_tooltips_enable (button->tooltips);
 			break;
 		case E_SIDEBAR_MODE_BOTH:
 			if (INTERNAL_MODE (sidebar) == E_SIDEBAR_MODE_TEXT) {
@@ -645,7 +703,6 @@ set_mode_internal (ESidebar *sidebar, ESidebarMode mode )
 							 NULL);
 			}
 
-			gtk_tooltips_disable (button->tooltips);
 			gtk_box_pack_start (GTK_BOX (button->hbox), button->label, TRUE, TRUE, 0);
 			gtk_widget_show (button->label);
 			break;
@@ -660,8 +717,8 @@ style_changed_notify (GConfClient *gconf, guint id, GConfEntry *entry, void *dat
 {
 	ESidebar *sidebar = data;
  	char *val;
- 	int mode;	
- 
+ 	int mode;
+
 	val = gconf_client_get_string (gconf, "/desktop/gnome/interface/toolbar_style", NULL);
 	if (val == NULL || !gconf_string_to_enum (toolbar_styles, val, &mode))
 		mode = E_SIDEBAR_MODE_BOTH;
@@ -685,9 +742,9 @@ e_sidebar_set_mode (ESidebar *sidebar, ESidebarMode mode)
 		if (sidebar->priv->style_changed_id) {
 			gconf_client_notify_remove (gconf_client, sidebar->priv->style_changed_id);
 			sidebar->priv->style_changed_id = 0;
-		}		
+		}
 	}
-	
+
 	if (mode != E_SIDEBAR_MODE_TOOLBAR) {
 		set_mode_internal (sidebar, mode);
 
@@ -704,7 +761,7 @@ e_sidebar_set_mode (ESidebar *sidebar, ESidebarMode mode)
 									   style_changed_notify, sidebar, NULL, NULL);
 		style_changed_notify (gconf_client, 0, NULL, sidebar);
 	}
-	
+
 	g_object_unref (gconf_client);
 
 	sidebar->priv->mode = mode;
@@ -717,7 +774,7 @@ e_sidebar_set_show_buttons  (ESidebar *sidebar, gboolean show)
 
 	if (sidebar->priv->show == show)
 		return;
-	
+
 	for (p = sidebar->priv->buttons; p != NULL; p = p->next) {
 		Button *button = p->data;
 
@@ -731,7 +788,7 @@ e_sidebar_set_show_buttons  (ESidebar *sidebar, gboolean show)
 
 	gtk_widget_queue_resize (GTK_WIDGET (sidebar));
 }
-		
+
 gboolean
 e_sidebar_get_show_buttons  (ESidebar *sidebar)
 {
