@@ -1,23 +1,23 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
-/* e-user-creatable-items-handler.c
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
+/*
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * Author: Ettore Perazzoli <ettore@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,7 +36,7 @@
 #include <bonobo/bonobo-control.h>
 
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <stdlib.h>
 #include <ctype.h>
@@ -60,6 +60,7 @@ struct _MenuItem {
 	char *tooltip;
 	char *component;
 	GdkPixbuf *icon;
+	GdkPixbuf *icon_toolbar;
 };
 typedef struct _MenuItem MenuItem;
 
@@ -258,8 +259,13 @@ ensure_menu_items (EUserCreatableItemsHandler *handler)
 
 				if (corba_item->iconName == NULL || *corba_item->iconName == '\0') {
 					item->icon = NULL;
+					item->icon_toolbar = NULL;
 				} else {
 					item->icon = e_icon_factory_get_icon (corba_item->iconName, E_ICON_SIZE_MENU);
+					if (item_is_default (item, component->alias))
+						item->icon_toolbar = e_icon_factory_get_icon (corba_item->iconName, E_ICON_SIZE_LARGE_TOOLBAR);
+					else
+						item->icon_toolbar = NULL;
 				}
 
 				if (corba_item->type == GNOME_Evolution_CREATABLE_OBJECT)
@@ -304,6 +310,9 @@ free_menu_items (GSList *menu_items)
 		if (item->icon != NULL)
 			g_object_unref (item->icon);
 
+		if (item->icon_toolbar != NULL)
+			g_object_unref (item->icon_toolbar);
+
 		g_free (item->component);
 		g_free (item);
 	}
@@ -698,7 +707,7 @@ new_button_change (GConfClient *gconf,
 	val = gconf_client_get_string (gconf, "/desktop/gnome/interface/toolbar_style", NULL);
 
 	set_combo_button_style (E_COMBO_BUTTON (priv->new_button),
-				val, priv->default_menu_item->icon);
+				val, priv->default_menu_item->icon_toolbar ? priv->default_menu_item->icon_toolbar : priv->default_menu_item->icon);
 
 	g_free (val);
 	gtk_widget_show (priv->new_button);
@@ -738,7 +747,7 @@ setup_toolbar_button (EUserCreatableItemsHandler *handler)
 	gtk_widget_set_sensitive (priv->new_button, TRUE);
 
 	set_combo_button_style (E_COMBO_BUTTON (priv->new_button),
-				val, priv->default_menu_item->icon);
+				val, priv->default_menu_item->icon_toolbar ? priv->default_menu_item->icon_toolbar : priv->default_menu_item->icon);
 
 	gconf_client_notify_add(gconf,"/desktop/gnome/interface/toolbar_style",
 		(GConfClientNotifyFunc)new_button_change, handler, NULL, NULL);
@@ -829,6 +838,9 @@ e_user_creatable_items_handler_class_init (EUserCreatableItemsHandlerClass *klas
 {
 	GObjectClass *object_class;
 
+	bindtextdomain (GETTEXT_PACKAGE, EVOLUTION_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
 	object_class = G_OBJECT_CLASS (klass);
 	object_class->dispose      = impl_dispose;
 	object_class->finalize     = impl_finalize;
